
/* In the SMART design described in our example (and in the paper: Experimental Design and Primary Data 
Analysis Methods for Comparing Adaptive Interventions"), responders to the first-stage intervention 
were not re-randomized to second-stage intervention options, so the chance that a randomly selected 
child has received intervention options consistent with any one of the four adaptive interventions 
depends on whether the child responded adequately to the first-stage intervention. Therefore the syntax 
below involves restructuring the data set such that we can use the SAS GENMOD procedure. 

First, we replicated observations (i.e.,rows in the original dataset lib.data) of responders, such that
instead of one observation per responder, the new dataset (lib.data2) includes two identical observations 
per responder. For each responder,A2 is set to equal 1 for the original observation and -1 for the other 
replicated observation. Accordingly, if the original dataset lib.data includes 67 observations for 
responders (and 150 observations in total), the new dataset lib.data2 includes 134 observations for 
responders (and 217 observations in total), in which A2=1 for half and A2=-1 for the other half. The 
number of observations for non-responders remains the same (83 observations for non-responders). 

Second, we assigned a weight to each observation in the new data set lib.data2 in order to make 
population-level inference (see Zanutto, Lu & Hornik, 2005 for more details). We created a new variable 
named ``weight'' in the lib.data2 data set, assigning a weight equal to 2 to each responder and 4 
to each non-responder.

Finally we use the SAS GENMOD procedure to compare the four adaptive interventions embedded in the SMART
design. 

***Please see the paper "Experimental Design and Primary Data Analysis Methods for Comparing Adaptive 
Interventions" for more details concerning this analysis.*** 


/* The following data step replicates observations for responders and assigns the weights.*/


DATA lib.data2;
          SET lib.data;
      IF R = 1 THEN DO;
                        ob = 1; A2 = -1; weight = 2; 
OUTPUT; 
                        ob = 2; A2 = 1; weight = 2; 
OUTPUT;
                   END;
      ELSE IF R = 0 THEN DO;
                            ob = 1; weight = 4; 
                            OUTPUT;
                        END; 
run;


/* The following GENMOD procedure compares the outcomes of the four adaptive interventions that
are embedded in the SMART design, as we describe on the webpage.*/

PROC GENMOD data = lib.data2;
CLASS id;
MODEL Y = A1 A2 A1*A2 O11 O12 O13;
SCWGT weight;
REPEATED SUBJECT=id / type = ind;
ESTIMATE 'difference 1, -1 and -1, -1' A1 2 A2 0 A1*A2 -2;
ESTIMATE 'difference 1, 1 and -1, 1' A1 2 A2 0 A1*A2 2;
ESTIMATE 'difference 1, -1 and 1, 1' A1 0 A2 -2 A1*A2 -2;
ESTIMATE 'difference 1, -1 and -1, 1' A1 2 A2 -2 A1*A2 0;
ESTIMATE 'difference -1, -1 and 1, 1' A1 -2 A2 -2 A1*A2 0;
ESTIMATE 'difference -1, 1 and -1, -1' A1 0 A2 2 A1*A2 -2;
RUN;
 



